---
meta:
    title: Spatial Picker
    description:
layout: component
---

## Examples

### Default Spatial Picker

```html:preview
<div style="height: 300px;">
    <terra-spatial-picker initial-value="-100, -50, 30, 50" ></terra-spatial-picker>
</div>
```

### Configured Spatial Picker

```html:preview
<div style="height: 300px;">
<terra-spatial-picker has-navigation has-shape-selector has-coord-tracker></terra-spatial-picker>
</div>
```

[component-metadata:terra-spatial-picker]
